@@ -1,20 +1,18 @@
 /* Implementation of the internal dcigettext function.
-   Copyright (C) 1995-1999, 2000-2009 Free Software Foundation, Inc.
+   Copyright (C) 1995-1999, 2000-2010, 2012 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as published by
+   the Free Software Foundation; either version 2.1 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* Tell glibc's <string.h> to provide a prototype for mempcpy().
    This must come before <config.h> because <config.h> may include
@@ -374,7 +372,7 @@ static const char *get_output_charset (struct binding *domainbinding)
 #endif
 
 
-/* For those loosing systems which don't have `alloca' we have to add
+/* For those losing systems which don't have `alloca' we have to add
    some additional code emulating it.  */
 #ifdef HAVE_ALLOCA
 /* Nothing has to be done.  */
@@ -507,6 +505,7 @@ DCIGETTEXT (const char *domainname, const char *msgid1, const char *msgid2,
   const char *localename;
 #endif
   size_t domainname_len;
+  size_t xdomainname_len;
 
   /* If no real MSGID is given return NULL.  */
   if (msgid1 == NULL)
@@ -627,6 +626,7 @@ DCIGETTEXT (const char *domainname, const char *msgid1, const char *msgid2,
 	  /* We have a relative path.  Make it absolute now.  */
 	  size_t dirname_len = strlen (dirname) + 1;
 	  size_t path_max;
+	  size_t resolved_dirname_len;
 	  char *resolved_dirname;
 	  char *ret;
 
@@ -635,7 +635,8 @@ DCIGETTEXT (const char *domainname, const char *msgid1, const char *msgid2,
 
 	  for (;;)
 	    {
-	      resolved_dirname = (char *) alloca (path_max + dirname_len);
+	      resolved_dirname_len = path_max + dirname_len;
+	      resolved_dirname = (char *) alloca (resolved_dirname_len);
 	      ADD_BLOCK (block_list, tmp_dirname);
 
 	      __set_errno (0);
@@ -652,7 +653,8 @@ DCIGETTEXT (const char *domainname, const char *msgid1, const char *msgid2,
 	       error but simply return the default string.  */
 	    goto return_untranslated;
 
-	  stpcpy (stpcpy (strchr (resolved_dirname, '\0'), "/"), dirname);
+	  strlcat (resolved_dirname, "/", resolved_dirname_len);
+	  strlcat (resolved_dirname, dirname, resolved_dirname_len);
 	  dirname = resolved_dirname;
 	}
 #ifndef IN_LIBGLOCALE
@@ -670,13 +672,14 @@ DCIGETTEXT (const char *domainname, const char *msgid1, const char *msgid2,
 #endif
 
   domainname_len = strlen (domainname);
-  xdomainname = (char *) alloca (strlen (categoryname)
-				 + domainname_len + 5);
+  xdomainname_len = strlen (categoryname) + domainname_len + 5;
+  xdomainname = (char *) alloca (xdomainname_len);
   ADD_BLOCK (block_list, xdomainname);
 
-  stpcpy ((char *) mempcpy (stpcpy (stpcpy (xdomainname, categoryname), "/"),
-			    domainname, domainname_len),
-	  ".mo");
+  strlcpy (xdomainname, categoryname, xdomainname_len);
+  strlcat (xdomainname, "/", xdomainname_len);
+  strlcat (xdomainname, domainname, xdomainname_len);
+  strlcat (xdomainname, ".mo", xdomainname_len);
 
   /* Creating working area.  */
   single_locale = (char *) alloca (strlen (categoryvalue) + 1);
@@ -1157,7 +1160,8 @@ _nl_find_msg (struct loaded_l10nfile *domain_file,
 #  if HAVE_ICONV
 		      /* When using GNU libc >= 2.2 or GNU libiconv >= 1.5,
 			 we want to use transliteration.  */
-#   if (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 2) || __GLIBC__ > 2 \
+#   if (((__GLIBC__ == 2 && __GLIBC_MINOR__ >= 2) || __GLIBC__ > 2) \
+	&& !defined __UCLIBC__) \
        || _LIBICONV_VERSION >= 0x0105
 		      if (strchr (outcharset, '/') == NULL)
 			{
